.. _rconf-reference:

************************************************************************
Reference
************************************************************************

.. automodule:: rconf

.. toctree::
    :maxdepth: 2
    :caption: Content

    reference/value
    reference/pointer
    reference/decode
    reference/patch
    reference/load
    reference/convenience
    reference/cli
    reference/error
